@@ -16,13 +16,22 @@ limitations under the License.
 
 package config
 
-import "k8s.io/kops/upup/pkg/fi/cloudup/awsup"
+import (
+	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
+	gcetpm "k8s.io/kops/upup/pkg/fi/cloudup/gce/tpm"
+)
 
 type Options struct {
 	Cloud                 string         `json:"cloud,omitempty"`
 	ConfigBase            string         `json:"configBase,omitempty"`
 	Server                *ServerOptions `json:"server,omitempty"`
 	CacheNodeidentityInfo bool           `json:"cacheNodeidentityInfo,omitempty"`
+
+	// EnableCloudIPAM enables the cloud IPAM controller.
+	EnableCloudIPAM bool `json:"enableCloudIPAM,omitempty"`
+
+	// Discovery configures options relating to discovery, particularly for gossip mode.
+	Discovery *DiscoveryOptions `json:"discovery,omitempty"`
 }
 
 func (o *Options) PopulateDefaults() {
@@ -46,8 +55,18 @@ type ServerOptions struct {
 	SigningCAs []string `json:"signingCAs"`
 	// CertNames is the list of active certificate names.
 	CertNames []string `json:"certNames"`
+
+	// UseInstanceIDForNodeName uses the instance ID instead of the hostname for the node name.
+	UseInstanceIDForNodeName bool `json:"useInstanceIDForNodeName,omitempty"`
 }
 
 type ServerProviderOptions struct {
-	AWS *awsup.AWSVerifierOptions `json:"aws,omitempty"`
+	AWS *awsup.AWSVerifierOptions  `json:"aws,omitempty"`
+	GCE *gcetpm.TPMVerifierOptions `json:"gce,omitempty"`
+}
+
+// DiscoveryOptions configures our support for discovery, particularly gossip DNS (i.e. k8s.local)
+type DiscoveryOptions struct {
+	// Enabled specifies whether support for discovery population is enabled.
+	Enabled bool `json:"enabled"`
 }
