@@ -20,12 +20,16 @@ import (
 	"testing"
 
 	"k8s.io/kops/upup/pkg/fi"
+	"k8s.io/kops/util/pkg/distributions"
 )
 
 func TestKubectlBuilder(t *testing.T) {
 	RunGoldenTest(t, "tests/golden/minimal", "kubectl", func(nodeupModelContext *NodeupModelContext, target *fi.ModelBuilderContext) error {
 		nodeupModelContext.Assets = fi.NewAssetStore("")
 		nodeupModelContext.Assets.AddForTest("kubectl", "/path/to/kubectl/asset", "testing kubectl content")
+		// NodeUp looks for the default user and group on the machine running the tests.
+		// Flatcar is unlikely to be used for such task, so tests results should be consistent.
+		nodeupModelContext.Distribution = distributions.DistributionFlatcar
 		builder := KubectlBuilder{NodeupModelContext: nodeupModelContext}
 		return builder.Build(target)
 	})
