@@ -144,48 +144,6 @@ func TestSetClusterFields(t *testing.T) {
 				},
 			},
 		},
-		{
-			Fields: []string{
-				"cluster.spec.etcdClusters[*].enableEtcdTLS=true",
-			},
-			Input: kops.Cluster{
-				Spec: kops.ClusterSpec{
-					EtcdClusters: []kops.EtcdClusterSpec{
-						{Name: "one", EnableEtcdTLS: true},
-						{Name: "two", EnableEtcdTLS: false},
-					},
-				},
-			},
-			Output: kops.Cluster{
-				Spec: kops.ClusterSpec{
-					EtcdClusters: []kops.EtcdClusterSpec{
-						{Name: "one", EnableEtcdTLS: true},
-						{Name: "two", EnableEtcdTLS: true},
-					},
-				},
-			},
-		},
-		{
-			Fields: []string{
-				"cluster.spec.etcdClusters[*].enableTLSAuth=true",
-			},
-			Input: kops.Cluster{
-				Spec: kops.ClusterSpec{
-					EtcdClusters: []kops.EtcdClusterSpec{
-						{Name: "one", EnableTLSAuth: true},
-						{Name: "two", EnableTLSAuth: false},
-					},
-				},
-			},
-			Output: kops.Cluster{
-				Spec: kops.ClusterSpec{
-					EtcdClusters: []kops.EtcdClusterSpec{
-						{Name: "one", EnableTLSAuth: true},
-						{Name: "two", EnableTLSAuth: true},
-					},
-				},
-			},
-		},
 		{
 			Fields: []string{
 				"cluster.spec.etcdClusters[*].version=v3.2.1",
@@ -207,27 +165,6 @@ func TestSetClusterFields(t *testing.T) {
 				},
 			},
 		},
-		{
-			Fields: []string{
-				"cluster.spec.etcdClusters[*].provider=Manager",
-			},
-			Input: kops.Cluster{
-				Spec: kops.ClusterSpec{
-					EtcdClusters: []kops.EtcdClusterSpec{
-						{Name: "one", Provider: kops.EtcdProviderTypeLegacy},
-						{Name: "two"},
-					},
-				},
-			},
-			Output: kops.Cluster{
-				Spec: kops.ClusterSpec{
-					EtcdClusters: []kops.EtcdClusterSpec{
-						{Name: "one", Provider: kops.EtcdProviderTypeManager},
-						{Name: "two", Provider: kops.EtcdProviderTypeManager},
-					},
-				},
-			},
-		},
 		{
 			Fields: []string{
 				"cluster.spec.etcdClusters[*].image=etcd-manager:v1.2.3",
@@ -258,7 +195,7 @@ func TestSetClusterFields(t *testing.T) {
 				Spec: kops.ClusterSpec{
 					Networking: &kops.NetworkingSpec{
 						Cilium: &kops.CiliumNetworkingSpec{
-							Ipam: "on",
+							IPAM: "on",
 						},
 					},
 				},
@@ -296,14 +233,14 @@ func TestSetClusterFields(t *testing.T) {
 		},
 		{
 			Fields: []string{
-				"cluster.spec.networking.cilium.disableMasquerade=true",
+				"cluster.spec.networking.cilium.masquerade=false",
 			},
 			Input: kops.Cluster{},
 			Output: kops.Cluster{
 				Spec: kops.ClusterSpec{
 					Networking: &kops.NetworkingSpec{
 						Cilium: &kops.CiliumNetworkingSpec{
-							DisableMasquerade: fi.Bool(true),
+							Masquerade: fi.Bool(false),
 						},
 					},
 				},
@@ -366,7 +303,7 @@ func TestSetCiliumFields(t *testing.T) {
 			Fields: []string{
 				"cluster.spec.networking.cilium.ipam=eni",
 				"cluster.spec.networking.cilium.enableNodePort=true",
-				"cluster.spec.networking.cilium.disableMasquerade=true",
+				"cluster.spec.networking.cilium.masquerade=false",
 				"cluster.spec.kubeProxy.enabled=false",
 			},
 			Input: kops.Cluster{
@@ -379,9 +316,9 @@ func TestSetCiliumFields(t *testing.T) {
 					},
 					Networking: &kops.NetworkingSpec{
 						Cilium: &kops.CiliumNetworkingSpec{
-							Ipam:              "eni",
-							EnableNodePort:    true,
-							DisableMasquerade: fi.Bool(true),
+							IPAM:           "eni",
+							EnableNodePort: true,
+							Masquerade:     fi.Bool(false),
 						},
 					},
 				},
