@@ -26,8 +26,6 @@ import (
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/apis/kops/model"
 	"k8s.io/kops/upup/pkg/fi"
-	"k8s.io/kops/upup/pkg/fi/cloudup/alitasks"
-	"k8s.io/kops/upup/pkg/fi/cloudup/aliup"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awstasks"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
 	"k8s.io/kops/upup/pkg/fi/cloudup/azure"
@@ -36,6 +34,8 @@ import (
 	"k8s.io/kops/upup/pkg/fi/cloudup/dotasks"
 	"k8s.io/kops/upup/pkg/fi/cloudup/gce"
 	"k8s.io/kops/upup/pkg/fi/cloudup/gcetasks"
+	"k8s.io/kops/upup/pkg/fi/cloudup/hetzner"
+	"k8s.io/kops/upup/pkg/fi/cloudup/hetznertasks"
 	"k8s.io/kops/upup/pkg/fi/cloudup/openstack"
 	"k8s.io/kops/upup/pkg/fi/cloudup/openstacktasks"
 )
@@ -47,7 +47,6 @@ const (
 	DefaultAWSEtcdVolumeGp3Iops       = 3000
 	DefaultAWSEtcdVolumeGp3Throughput = 125
 	DefaultGCEEtcdVolumeType          = "pd-ssd"
-	DefaultALIEtcdVolumeType          = "cloud_ssd"
 )
 
 // MasterVolumeBuilder builds master EBS volumes
@@ -62,7 +61,8 @@ func (b *MasterVolumeBuilder) Build(c *fi.ModelBuilderContext) error {
 	for _, etcd := range b.Cluster.Spec.EtcdClusters {
 		for _, m := range etcd.Members {
 			// EBS volume for each member of the each etcd cluster
-			name := m.Name + ".etcd-" + etcd.Name + "." + b.ClusterName()
+			prefix := m.Name + ".etcd-" + etcd.Name
+			name := prefix + "." + b.ClusterName()
 
 			igName := fi.StringValue(m.InstanceGroup)
 			if igName == "" {
@@ -96,7 +96,7 @@ func (b *MasterVolumeBuilder) Build(c *fi.ModelBuilderContext) error {
 			}
 			sort.Strings(allMembers)
 
-			switch kops.CloudProviderID(b.Cluster.Spec.CloudProvider) {
+			switch b.Cluster.Spec.GetCloudProvider() {
 			case kops.CloudProviderAWS:
 				err = b.addAWSVolume(c, name, volumeSize, zone, etcd, m, allMembers)
 				if err != nil {
@@ -105,18 +105,18 @@ func (b *MasterVolumeBuilder) Build(c *fi.ModelBuilderContext) error {
 			case kops.CloudProviderDO:
 				b.addDOVolume(c, name, volumeSize, zone, etcd, m, allMembers)
 			case kops.CloudProviderGCE:
-				b.addGCEVolume(c, name, volumeSize, zone, etcd, m, allMembers)
+				b.addGCEVolume(c, prefix, volumeSize, zone, etcd, m, allMembers)
+			case kops.CloudProviderHetzner:
+				b.addHetznerVolume(c, name, volumeSize, zone, etcd, m, allMembers)
 			case kops.CloudProviderOpenstack:
 				err = b.addOpenstackVolume(c, name, volumeSize, zone, etcd, m, allMembers)
 				if err != nil {
 					return err
 				}
-			case kops.CloudProviderALI:
-				b.addALIVolume(c, name, volumeSize, zone, etcd, m, allMembers)
 			case kops.CloudProviderAzure:
 				b.addAzureVolume(c, name, volumeSize, zone, etcd, m, allMembers)
 			default:
-				return fmt.Errorf("unknown cloudprovider %q", b.Cluster.Spec.CloudProvider)
+				return fmt.Errorf("unknown cloudprovider %q", b.Cluster.Spec.GetCloudProvider())
 			}
 		}
 	}
@@ -242,7 +242,7 @@ func (b *MasterVolumeBuilder) addDOVolume(c *fi.ModelBuilderContext, name string
 	c.AddTask(t)
 }
 
-func (b *MasterVolumeBuilder) addGCEVolume(c *fi.ModelBuilderContext, name string, volumeSize int32, zone string, etcd kops.EtcdClusterSpec, m kops.EtcdMemberSpec, allMembers []string) {
+func (b *MasterVolumeBuilder) addGCEVolume(c *fi.ModelBuilderContext, prefix string, volumeSize int32, zone string, etcd kops.EtcdClusterSpec, m kops.EtcdMemberSpec, allMembers []string) {
 	volumeType := fi.StringValue(m.VolumeType)
 	if volumeType == "" {
 		volumeType = DefaultGCEEtcdVolumeType
@@ -271,10 +271,11 @@ func (b *MasterVolumeBuilder) addGCEVolume(c *fi.ModelBuilderContext, name strin
 	tags[gce.GceLabelNameEtcdClusterPrefix+etcd.Name] = gce.EncodeGCELabel(clusterSpec)
 
 	// GCE disk names must match the following regular expression: '[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?'
-	name = strings.Replace(name, ".", "-", -1)
-	if strings.IndexByte("0123456789-", name[0]) != -1 {
-		name = "d" + name
+	prefix = strings.Replace(prefix, ".", "-", -1)
+	if strings.IndexByte("0123456789-", prefix[0]) != -1 {
+		prefix = "d" + prefix
 	}
+	name := gce.ClusterSuffixedName(prefix, b.Cluster.ObjectMeta.Name, 63)
 
 	t := &gcetasks.Disk{
 		Name:      fi.String(name),
@@ -289,6 +290,24 @@ func (b *MasterVolumeBuilder) addGCEVolume(c *fi.ModelBuilderContext, name strin
 	c.AddTask(t)
 }
 
+func (b *MasterVolumeBuilder) addHetznerVolume(c *fi.ModelBuilderContext, name string, volumeSize int32, zone string, etcd kops.EtcdClusterSpec, m kops.EtcdMemberSpec, allMembers []string) {
+	tags := make(map[string]string)
+	tags[hetzner.TagKubernetesClusterName] = b.Cluster.ObjectMeta.Name
+	tags[hetzner.TagKubernetesInstanceGroup] = fi.StringValue(m.InstanceGroup)
+	tags[hetzner.TagKubernetesVolumeRole] = etcd.Name
+
+	t := &hetznertasks.Volume{
+		Name:      fi.String(name),
+		Lifecycle: b.Lifecycle,
+		Size:      int(volumeSize),
+		Location:  zone,
+		Labels:    tags,
+	}
+	c.AddTask(t)
+
+	return
+}
+
 func (b *MasterVolumeBuilder) addOpenstackVolume(c *fi.ModelBuilderContext, name string, volumeSize int32, zone string, etcd kops.EtcdClusterSpec, m kops.EtcdMemberSpec, allMembers []string) error {
 	volumeType := fi.StringValue(m.VolumeType)
 
@@ -304,8 +323,8 @@ func (b *MasterVolumeBuilder) addOpenstackVolume(c *fi.ModelBuilderContext, name
 	tags[openstack.TagNameRolePrefix+"master"] = "1"
 
 	// override zone
-	if b.Cluster.Spec.CloudConfig.Openstack.BlockStorage != nil && b.Cluster.Spec.CloudConfig.Openstack.BlockStorage.OverrideAZ != nil {
-		zone = fi.StringValue(b.Cluster.Spec.CloudConfig.Openstack.BlockStorage.OverrideAZ)
+	if b.Cluster.Spec.CloudProvider.Openstack.BlockStorage != nil && b.Cluster.Spec.CloudProvider.Openstack.BlockStorage.OverrideAZ != nil {
+		zone = fi.StringValue(b.Cluster.Spec.CloudProvider.Openstack.BlockStorage.OverrideAZ)
 	}
 	t := &openstacktasks.Volume{
 		Name:             fi.String(name),
@@ -320,44 +339,6 @@ func (b *MasterVolumeBuilder) addOpenstackVolume(c *fi.ModelBuilderContext, name
 	return nil
 }
 
-func (b *MasterVolumeBuilder) addALIVolume(c *fi.ModelBuilderContext, name string, volumeSize int32, zone string, etcd kops.EtcdClusterSpec, m kops.EtcdMemberSpec, allMembers []string) {
-	// Alicloud does not support volumeName starts with number
-	name = "v" + name
-	volumeType := fi.StringValue(m.VolumeType)
-	if volumeType == "" {
-		volumeType = DefaultALIEtcdVolumeType
-	}
-
-	// The tags are how protokube knows to mount the volume and use it for etcd
-	tags := make(map[string]string)
-
-	// Apply all user defined labels on the volumes
-	for k, v := range b.Cluster.Spec.CloudLabels {
-		tags[k] = v
-	}
-
-	// This is the configuration of the etcd cluster
-	tags[aliup.TagNameEtcdClusterPrefix+etcd.Name] = m.Name + "/" + strings.Join(allMembers, ",")
-	// This says "only mount on a master"
-	tags[aliup.TagNameRolePrefix+"master"] = "1"
-	// We always add an owned tags (these can't be shared)
-	tags["kubernetes.io/cluster/"+b.Cluster.ObjectMeta.Name] = "owned"
-
-	encrypted := fi.BoolValue(m.EncryptedVolume)
-
-	t := &alitasks.Disk{
-		Lifecycle:    b.Lifecycle,
-		Name:         fi.String(name),
-		ZoneId:       fi.String(zone),
-		SizeGB:       fi.Int(int(volumeSize)),
-		DiskCategory: fi.String(volumeType),
-		Encrypted:    fi.Bool(encrypted),
-		Tags:         tags,
-	}
-
-	c.AddTask(t)
-}
-
 func (b *MasterVolumeBuilder) addAzureVolume(
 	c *fi.ModelBuilderContext,
 	name string,
