@@ -23,9 +23,11 @@ import (
 
 	compute "google.golang.org/api/compute/v1"
 	clouddns "google.golang.org/api/dns/v1"
+	"google.golang.org/api/iam/v1"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/pkg/dns"
 	"k8s.io/kops/pkg/resources"
+	"k8s.io/kops/pkg/truncate"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/gce"
 )
@@ -41,12 +43,15 @@ const (
 	typeFirewallRule         = "FirewallRule"
 	typeForwardingRule       = "ForwardingRule"
 	typeHTTPHealthcheck      = "HTTP HealthCheck"
+	typeHealthcheck          = "HealthCheck"
 	typeAddress              = "Address"
 	typeRoute                = "Route"
 	typeNetwork              = "Network"
 	typeSubnet               = "Subnet"
 	typeRouter               = "Router"
 	typeDNSRecord            = "DNSRecord"
+	typeServiceAccount       = "ServiceAccount"
+	typeBackendService       = "BackendService"
 )
 
 // Maximum number of `-` separated tokens in a name
@@ -106,6 +111,9 @@ func ListResourcesGCE(gceCloud gce.GCECloud, clusterName string, region string)
 		d.listSubnets,
 		d.listRouters,
 		d.listNetworks,
+		d.listServiceAccounts,
+		d.listBackendServices,
+		d.listHealthchecks,
 	}
 	for _, fn := range listFunctions {
 		resourceTrackers, err := fn()
@@ -401,6 +409,25 @@ func (d *clusterDiscoveryGCE) listTargetPools() ([]*resources.Resource, error) {
 
 		klog.V(4).Infof("Found resource: %s", tp.SelfLink)
 		resourceTrackers = append(resourceTrackers, resourceTracker)
+
+		for _, healthCheckLink := range tp.HealthChecks {
+			healthCheckName := gce.LastComponent(healthCheckLink)
+			hc, err := c.Compute().HTTPHealthChecks().Get(c.Project(), healthCheckName)
+			if err != nil {
+				return nil, fmt.Errorf("error getting HTTPHealthCheck %q: %w", healthCheckName, err)
+			}
+
+			healthCheckResource := &resources.Resource{
+				Name:    hc.Name,
+				ID:      hc.Name,
+				Type:    typeHTTPHealthcheck,
+				Deleter: deleteHTTPHealthCheck,
+				Obj:     hc,
+			}
+			healthCheckResource.Blocked = append(healthCheckResource.Blocked, resourceTracker.Type+":"+resourceTracker.ID)
+			resourceTrackers = append(resourceTrackers, healthCheckResource)
+		}
+
 	}
 
 	return resourceTrackers, nil
@@ -498,89 +525,153 @@ func (d *clusterDiscoveryGCE) listFirewallRules() ([]*resources.Resource, error)
 
 	ctx := context.Background()
 
-	frs, err := c.Compute().Firewalls().List(ctx, c.Project())
+	firewallRules, err := c.Compute().Firewalls().List(ctx, c.Project())
 	if err != nil {
 		return nil, fmt.Errorf("error listing FirewallRules: %v", err)
 	}
 
-	for _, fr := range frs {
-		if !d.matchesClusterNameMultipart(fr.Name, maxPrefixTokens) && !strings.HasPrefix(fr.Name, "k8s-") {
+nextFirewallRule:
+	for _, firewallRule := range firewallRules {
+		if !d.matchesClusterNameMultipart(firewallRule.Name, maxPrefixTokens) && !strings.HasPrefix(firewallRule.Name, "k8s-") {
 			continue
 		}
 
-		foundMatchingTarget := false
+		// TODO: Check network?  (or other fields?)  No label support currently.
+
+		// We consider only firewall rules that target our cluster tags, which include the cluster name or hash
 		tagPrefix := gce.SafeClusterName(d.clusterName) + "-"
-		for _, target := range fr.TargetTags {
-			if strings.HasPrefix(target, tagPrefix) {
-				foundMatchingTarget = true
+		clusterNameHash := truncate.HashString(gce.SafeClusterName(d.clusterName), 6)
+		if len(firewallRule.TargetTags) != 0 {
+			tagMatchCount := 0
+			for _, target := range firewallRule.TargetTags {
+				if strings.HasPrefix(target, tagPrefix) || strings.Contains(target, clusterNameHash) {
+					tagMatchCount++
+				}
+			}
+			if len(firewallRule.TargetTags) != tagMatchCount {
+				continue nextFirewallRule
 			}
 		}
-		if !foundMatchingTarget {
-			continue
+		// We don't have any rules that match only on source tags, but if we did we could check them here
+		if len(firewallRule.TargetTags) == 0 {
+			continue nextFirewallRule
 		}
 
-		// find the Kubernetes LoadBalancer
-		if strings.HasPrefix(fr.Name, "k8s-fw-") {
-			name := strings.ReplaceAll(fr.Name, "k8s-fw-", "")
-			fr, err := c.Compute().ForwardingRules().Get(c.Project(), c.Region(), name)
-			if err != nil {
-				return nil, fmt.Errorf("error get ForwardingRule: %v", err)
-			}
-
-			frResourceTracker := &resources.Resource{
-				Name:    fr.Name,
-				ID:      fr.Name,
-				Type:    typeForwardingRule,
-				Deleter: deleteForwardingRule,
-				Obj:     fr,
-			}
-			if fr.Target != "" {
-				frResourceTracker.Blocks = append(frResourceTracker.Blocks, typeTargetPool+":"+gce.LastComponent(fr.Target))
-			}
-			resourceTrackers = append(resourceTrackers, frResourceTracker)
-
-			tp, err := c.Compute().TargetPools().Get(c.Project(), c.Region(), name)
-			if err != nil {
-				return nil, fmt.Errorf("error get TargetPool: %v", err)
-			}
-
-			tpResourceTracker := &resources.Resource{
-				Name:    tp.Name,
-				ID:      tp.Name,
-				Type:    typeTargetPool,
-				Deleter: deleteTargetPool,
-				Obj:     tp,
-			}
-			resourceTrackers = append(resourceTrackers, tpResourceTracker)
-
-		}
-		// l4 level healthchecks
-		if strings.HasPrefix(fr.Name, "k8s-") && strings.HasSuffix(fr.Name, "-http-hc") {
-			name := strings.ReplaceAll(strings.ReplaceAll(fr.Name, "k8s-", ""), "-http-hc", "")
-			hc, err := c.Compute().HTTPHealthChecks().Get(c.Project(), name)
-			if err != nil {
-				return nil, fmt.Errorf("error get HTTPHealthCheck: %v", err)
-			}
-			hcResourceTracker := &resources.Resource{
-				Name:    hc.Name,
-				ID:      hc.Name,
-				Type:    typeHTTPHealthcheck,
-				Deleter: deleteHTTPHealthCheck,
-				Obj:     hc,
-			}
-			resourceTrackers = append(resourceTrackers, hcResourceTracker)
-		}
-
-		resourceTracker := &resources.Resource{
-			Name:    fr.Name,
-			ID:      fr.Name,
+		firewallRuleResource := &resources.Resource{
+			Name:    firewallRule.Name,
+			ID:      firewallRule.Name,
 			Type:    typeFirewallRule,
 			Deleter: deleteFirewallRule,
-			Obj:     fr,
+			Obj:     firewallRule,
+		}
+		firewallRuleResource.Blocks = append(firewallRuleResource.Blocks, typeNetwork+":"+gce.LastComponent(firewallRule.Network))
+
+		if d.matchesClusterNameMultipart(firewallRule.Name, maxPrefixTokens) {
+			klog.V(4).Infof("Found resource: %s", firewallRule.SelfLink)
+			resourceTrackers = append(resourceTrackers, firewallRuleResource)
 		}
 
-		klog.V(4).Infof("Found resource: %s", fr.SelfLink)
-		resourceTrackers = append(resourceTrackers, resourceTracker)
+		// find the objects if this is a Kubernetes LoadBalancer
+		if strings.HasPrefix(firewallRule.Name, "k8s-fw-") {
+			// We build a list of resources if this is a k8s firewall rule,
+			// but we only add them once all the checks are complete
+			var k8sResources []*resources.Resource
+
+			k8sResources = append(k8sResources, firewallRuleResource)
+
+			// We lookup the forwarding rule by name, but we then validate that it points to one of our resources
+			forwardingRuleName := strings.TrimPrefix(firewallRule.Name, "k8s-fw-")
+			forwardingRule, err := c.Compute().ForwardingRules().Get(c.Project(), c.Region(), forwardingRuleName)
+			if err != nil {
+				if gce.IsNotFound(err) {
+					// We looked it up by name, so an error isn't unlikely
+					klog.Warningf("could not find forwarding rule %q, assuming firewallRule %q is not a k8s rule", forwardingRuleName, firewallRule.Name)
+					continue nextFirewallRule
+				}
+				return nil, fmt.Errorf("error getting ForwardingRule %q: %w", forwardingRuleName, err)
+			}
+
+			forwardingRuleResource := &resources.Resource{
+				Name:    forwardingRule.Name,
+				ID:      forwardingRule.Name,
+				Type:    typeForwardingRule,
+				Deleter: deleteForwardingRule,
+				Obj:     forwardingRule,
+			}
+			if forwardingRule.Target != "" {
+				forwardingRuleResource.Blocks = append(forwardingRuleResource.Blocks, typeTargetPool+":"+gce.LastComponent(forwardingRule.Target))
+			}
+			k8sResources = append(k8sResources, forwardingRuleResource)
+
+			// TODO: Can we get k8s to set labels on the ForwardingRule?
+
+			// TODO: Check description?  It looks like e.g. description: '{"kubernetes.io/service-name":"kube-system/guestbook"}'
+
+			if forwardingRule.Target == "" {
+				klog.Warningf("forwarding rule %q did not have target, assuming firewallRule %q is not a k8s rule", forwardingRuleName, firewallRule.Name)
+				continue nextFirewallRule
+			}
+
+			targetPoolName := gce.LastComponent(forwardingRule.Target)
+			targetPool, err := c.Compute().TargetPools().Get(c.Project(), c.Region(), targetPoolName)
+			if err != nil {
+				return nil, fmt.Errorf("error getting TargetPool %q: %w", targetPoolName, err)
+			}
+
+			targetPoolResource := &resources.Resource{
+				Name:    targetPool.Name,
+				ID:      targetPool.Name,
+				Type:    typeTargetPool,
+				Deleter: deleteTargetPool,
+				Obj:     targetPool,
+			}
+			k8sResources = append(k8sResources, targetPoolResource)
+
+			// TODO: Check description? (looks like description: '{"kubernetes.io/service-name":"k8s-dbb09d49d9780e7e-node"}' )
+
+			// TODO: Check instances?
+
+			for _, healthCheckLink := range targetPool.HealthChecks {
+				// l4 level healthchecks
+
+				healthCheckName := gce.LastComponent(healthCheckLink)
+				if !strings.HasPrefix(healthCheckName, "k8s-") || !strings.Contains(healthCheckLink, "/httpHealthChecks/") {
+					klog.Warningf("found non-k8s healthcheck %q in targetPool %q, assuming firewallRule %q is not a k8s rule", healthCheckLink, targetPoolName, firewallRule.Name)
+					continue nextFirewallRule
+				}
+
+				hc, err := c.Compute().HTTPHealthChecks().Get(c.Project(), healthCheckName)
+				if err != nil {
+					return nil, fmt.Errorf("error getting HTTPHealthCheck %q: %w", healthCheckName, err)
+				}
+
+				// TODO: Check description? (looks like description: '{"kubernetes.io/service-name":"k8s-dbb09d49d9780e7e-node"}' )
+
+				healthCheckResource := &resources.Resource{
+					Name:    hc.Name,
+					ID:      hc.Name,
+					Type:    typeHTTPHealthcheck,
+					Deleter: deleteHTTPHealthCheck,
+					Obj:     hc,
+				}
+				healthCheckResource.Blocked = append(healthCheckResource.Blocked, targetPoolResource.Type+":"+targetPoolResource.ID)
+
+				k8sResources = append(k8sResources, healthCheckResource)
+
+			}
+
+			// We now have confidence that this is a k8s LoadBalancer; add the resources
+			resourceTrackers = append(resourceTrackers, k8sResources...)
+		}
+
+		// find the objects if this is a Kubernetes node health check
+		if strings.HasPrefix(firewallRule.Name, "k8s-") && strings.HasSuffix(firewallRule.Name, "-node-http-hc") {
+			// TODO: Check port matches http health check (always 10256?)
+			// TODO: Check description - looks like '{"kubernetes.io/cluster-id":"cb2e931dec561053"}'
+
+			// We already know the target tags match
+			resourceTrackers = append(resourceTrackers, firewallRuleResource)
+		}
 	}
 
 	return resourceTrackers, nil
@@ -904,6 +995,152 @@ func deleteRouter(cloud fi.Cloud, r *resources.Resource) error {
 	return c.WaitForOp(op)
 }
 
+func (d *clusterDiscoveryGCE) listServiceAccounts() ([]*resources.Resource, error) {
+	c := d.gceCloud
+	ctx := context.Background()
+
+	sas, err := c.IAM().ServiceAccounts().List(ctx, fmt.Sprintf("projects/%s", c.Project()))
+	if err != nil {
+		return nil, fmt.Errorf("error listing ServiceAccounts %w", err)
+	}
+	var resourceTrackers []*resources.Resource
+	for _, sa := range sas {
+		tokens := strings.Split(gce.LastComponent(sa.Name), "@")
+		if len(tokens) != 2 {
+			return nil, fmt.Errorf("Invalid service account email '%s'", gce.LastComponent(sa.Name))
+		}
+		accountID := tokens[0]
+		names := []string{gce.ControlPlane, gce.Bastion, gce.Node}
+		for _, name := range names {
+			generatedName := gce.ServiceAccountName(name, d.clusterName)
+			if generatedName == accountID {
+				resourceTracker := &resources.Resource{
+					Name:    gce.LastComponent(sa.Name),
+					ID:      sa.Name,
+					Type:    typeServiceAccount,
+					Deleter: deleteServiceAccount,
+					Obj:     sa,
+				}
+
+				klog.V(4).Infof("found resource: %s", sa.Name)
+				resourceTrackers = append(resourceTrackers, resourceTracker)
+				break
+			}
+		}
+	}
+	return resourceTrackers, nil
+}
+
+func deleteServiceAccount(cloud fi.Cloud, r *resources.Resource) error {
+	c := cloud.(gce.GCECloud)
+	o := r.Obj.(*iam.ServiceAccount)
+
+	klog.V(2).Infof("deleting GCE ServiceAccount %s", o.Name)
+	_, err := c.IAM().ServiceAccounts().Delete(o.Name)
+	return err
+}
+
+// containsOnlyListedIGMs returns true if all the given backend service's backends
+// are contained in the provided list of IGM resources.
+func containsOnlyListedIGMs(svc *compute.BackendService, igms []*resources.Resource) bool {
+	for _, be := range svc.Backends {
+		listed := false
+		for _, igm := range igms {
+			// NOTE: this should be sufficient / strict enough since IGM names include the cluster
+			// that they are part of, but revisit if naming conventions change.
+			if strings.HasSuffix(be.Group, "/"+igm.Name) {
+				listed = true
+				break
+			}
+		}
+
+		if !listed {
+			return false
+		}
+	}
+	return true
+}
+
+func (d *clusterDiscoveryGCE) listBackendServices() ([]*resources.Resource, error) {
+	c := d.gceCloud
+
+	svcs, err := c.Compute().RegionBackendServices().List(context.Background(), c.Project(), c.Region())
+	if err != nil {
+		if gce.IsNotFound(err) {
+			klog.Infof("backend services not found, assuming none exist in project: %q region: %q", c.Project(), c.Region())
+			return nil, nil
+		}
+		return nil, fmt.Errorf("Failed to list backend services: %w", err)
+	}
+	// TODO: cache, for efficiency, if needed.
+	// Find all relevant backend services by finding all the cluster's IGMs, and then
+	// listing all backend services in the project / region, then selecting
+	// the backend services which contain only the relevant IGMs.
+	igms, err := d.listInstanceGroupManagersAndInstances()
+	if err != nil {
+		return nil, err
+	}
+	var bs []*resources.Resource
+	for _, svc := range svcs {
+		if containsOnlyListedIGMs(svc, igms) {
+			bs = append(bs, &resources.Resource{
+				Name: svc.Name,
+				ID:   svc.Name,
+				Type: typeBackendService,
+				Deleter: func(cloud fi.Cloud, r *resources.Resource) error {
+					op, err := c.Compute().RegionBackendServices().Delete(c.Project(), c.Region(), svc.Name)
+					if err != nil {
+						return err
+					}
+					return c.WaitForOp(op)
+				},
+				Obj: svc,
+			})
+		}
+	}
+
+	return bs, nil
+}
+
+func (d *clusterDiscoveryGCE) listHealthchecks() ([]*resources.Resource, error) {
+	c := d.gceCloud
+	// TODO: cache, for efficiency, if needed.
+	// Find relevant healthchecks by finding all the backend services relevant to this
+	// cluster, then selecting all the healthchecks they use.
+	backendServices, err := d.listBackendServices()
+	if err != nil {
+		return nil, err
+	}
+	hcs := make(map[string]struct{})
+	for _, bs := range backendServices {
+		bsObj, ok := bs.Obj.(*compute.BackendService)
+		if !ok {
+			return nil, fmt.Errorf("%T is not a *compute.BackendService", bs)
+		}
+		for _, hc := range bsObj.HealthChecks {
+			hcs[hc] = struct{}{}
+		}
+	}
+	var hcResources []*resources.Resource
+	for hc := range hcs {
+		hcResources = append(hcResources, &resources.Resource{
+			Name: gce.LastComponent(hc),
+			ID:   gce.LastComponent(hc),
+			Type: typeHealthcheck,
+			Deleter: func(cloud fi.Cloud, r *resources.Resource) error {
+				op, err := c.Compute().RegionHealthChecks().Delete(c.Project(), c.Region(), gce.LastComponent(hc))
+				if err != nil {
+					return err
+				}
+				return c.WaitForOp(op)
+			},
+			Obj: hc,
+		})
+	}
+
+	return hcResources, nil
+}
+
 func (d *clusterDiscoveryGCE) listNetworks() ([]*resources.Resource, error) {
 	// Templates are very accurate because of the metadata, so use those as the sanity check
 	templates, err := d.findInstanceTemplates()
@@ -929,7 +1166,7 @@ func (d *clusterDiscoveryGCE) listNetworks() ([]*resources.Resource, error) {
 	}
 
 	for _, o := range networks.Items {
-		if o.Name != gce.SafeClusterName(d.clusterName) {
+		if o.Name != gce.SafeTruncatedClusterName(d.clusterName, 63) {
 			klog.V(8).Infof("skipping network with name %q", o.Name)
 			continue
 		}
@@ -999,7 +1236,11 @@ func (d *clusterDiscoveryGCE) matchesClusterNameMultipart(name string, maxParts
 		if id == "" {
 			continue
 		}
-		if name == gce.SafeObjectName(id, d.clusterName) {
+
+		safeName := gce.SafeObjectName(id, d.clusterName)
+		clusterNameHash := truncate.HashString(gce.SafeClusterName(d.clusterName), 6)
+
+		if name == safeName || strings.Contains(name, clusterNameHash) {
 			return true
 		}
 	}
