@@ -19,6 +19,8 @@ package builder
 import (
 	"fmt"
 	"os"
+	"path/filepath"
+	"strings"
 
 	"sigs.k8s.io/kubetest2/pkg/exec"
 )
@@ -39,5 +41,21 @@ func (b *BuildOptions) Build() error {
 	)
 	cmd.SetDir(b.KopsRoot)
 	exec.InheritOutput(cmd)
-	return cmd.Run()
+	if err := cmd.Run(); err != nil {
+		return err
+	}
+
+	// Write some meta files so that other tooling can know e.g. KOPS_BASE_URL
+	metaDir := filepath.Join(b.KopsRoot, ".kubetest2")
+
+	if err := os.MkdirAll(metaDir, 0o755); err != nil {
+		return fmt.Errorf("failed to Mkdir(%q): %w", metaDir, err)
+	}
+	p := filepath.Join(metaDir, "kops-base-url")
+	kopsBaseURL := strings.Replace(b.StageLocation, "gs://", "https://storage.googleapis.com/", 1)
+	if err := os.WriteFile(p, []byte(kopsBaseURL), 0o644); err != nil {
+		return fmt.Errorf("failed to WriteFile(%q): %w", p, err)
+	}
+
+	return nil
 }
