@@ -19,19 +19,19 @@ package do
 import (
 	"errors"
 	"math/rand"
+	"time"
 )
 
 var allZones = []string{
 	"nyc1",
 	"nyc3",
-	"sfo3",
-	"sfo2",
 	"tor1",
 	"lon1",
 	"sgp1",
 	"blr1",
-	"sfo2",
 	"sfo3",
+	"ams3",
+	"fra1",
 }
 
 // ErrNoEligibleRegion indicates the requested number of zones is not available in any region
@@ -46,7 +46,8 @@ func RandomZones(count int) ([]string, error) {
 		return nil, ErrMoreThanOneZone
 	}
 
-	n := rand.Int() % len(allZones)
+	rand.Seed(time.Now().UnixNano())
+	n := rand.Intn(1000) % len(allZones)
 	chosenZone := allZones[n]
 
 	chosenZones := make([]string, 0)
