@@ -22,11 +22,30 @@ if [ -z "${KOPS_VERSION_A-}" ] || [ -z "${K8S_VERSION_A-}" ] || [ -z "${KOPS_VER
   exit 1
 fi
 
+TEST_PACKAGE_VERSION="${K8S_VERSION_B}"
+
 if [[ "$K8S_VERSION_A" == "latest" ]]; then
-	K8S_VERSION_A=$(curl https://storage.googleapis.com/kubernetes-release/release/latest.txt)
+  K8S_VERSION_A=$(curl https://storage.googleapis.com/kubernetes-release/release/latest.txt)
 fi
 if [[ "$K8S_VERSION_B" == "latest" ]]; then
-	K8S_VERSION_B=$(curl https://storage.googleapis.com/kubernetes-release/release/latest.txt)
+  K8S_VERSION_B=$(curl https://storage.googleapis.com/kubernetes-release/release/latest.txt)
+  TEST_PACKAGE_MARKER="latest.txt"
+fi
+if [[ "$K8S_VERSION_A" == "stable" ]]; then
+  K8S_VERSION_A=$(curl https://storage.googleapis.com/kubernetes-release/release/stable.txt)
+fi
+if [[ "$K8S_VERSION_B" == "stable" ]]; then
+  K8S_VERSION_B=$(curl https://storage.googleapis.com/kubernetes-release/release/stable.txt)
+  TEST_PACKAGE_MARKER="stable.txt"
+fi
+if [[ "$K8S_VERSION_A" == "ci" ]]; then
+  K8S_VERSION_A=https://storage.googleapis.com/k8s-release-dev/ci/$(curl https://storage.googleapis.com/k8s-release-dev/ci/latest.txt)
+fi
+if [[ "$K8S_VERSION_B" == "ci" ]]; then
+  K8S_VERSION_B=https://storage.googleapis.com/k8s-release-dev/ci/$(curl https://storage.googleapis.com/k8s-release-dev/ci/latest.txt)
+  TEST_PACKAGE_MARKER="latest.txt"
+  TEST_PACKAGE_DIR="ci"
+  TEST_PACKAGE_BUCKET="k8s-release-dev"
 fi
 
 export KOPS_BASE_URL
@@ -41,11 +60,12 @@ else
   KOPS_BASE_URL=$(kops-base-from-marker "${KOPS_VERSION_B}")
   KOPS_BASE_URL_B="${KOPS_BASE_URL}"
   KOPS_B=$(kops-download-from-base)
+  CHANNELS=$(kops-channels-download-from-base)
 fi
 
 ${KUBETEST2} \
-		--down \
-		--kops-binary-path="${KOPS_B}" || echo "kubetest2 down failed"
+    --down \
+    --kops-binary-path="${KOPS_B}" || echo "kubetest2 down failed"
 
 # First kOps version may be a released version. If so, it is prefixed with v
 if [[ "${KOPS_VERSION_A:0:1}" == "v" ]]; then
@@ -58,11 +78,15 @@ else
   KOPS="${KOPS_A}"
 fi
 
+
+
 ${KUBETEST2} \
-		--up \
-		--kops-binary-path="${KOPS_A}" \
-		--kubernetes-version="${K8S_VERSION_A}" \
-		--create-args="--networking calico"
+    --up \
+    --kops-binary-path="${KOPS_A}" \
+    --kubernetes-version="${K8S_VERSION_A}" \
+    --control-plane-size="${KOPS_CONTROL_PLANE_SIZE:-1}" \
+    --template-path="${KOPS_TEMPLATE:-}" \
+    --create-args="--networking calico"
 
 # Export kubeconfig-a
 KUBECONFIG_A=$(mktemp -t kops.XXXXXXXXX)
@@ -90,7 +114,9 @@ fi
 kubectl get nodes -owide --kubeconfig "${KUBECONFIG_A}"
 
 # Sleep to ensure channels has done its thing
-sleep 60s
+sleep 120s
+
+${CHANNELS} apply channel "$KOPS_STATE_STORE"/"${CLUSTER_NAME}"/addons/bootstrap-channel.yaml --yes -v4
 
 "${KOPS_B}" rolling-update cluster
 "${KOPS_B}" rolling-update cluster --yes --validation-timeout 30m
@@ -108,10 +134,26 @@ if [[ -n ${KOPS_SKIP_E2E:-} ]]; then
   exit
 fi
 
+
+test_package_args="--parallel 25"
+
+if [[ -n ${TEST_PACKAGE_MARKER-} ]]; then
+  test_package_args+=" --test-package-marker=${TEST_PACKAGE_MARKER}"
+  if [[ -n ${TEST_PACKAGE_DIR-} ]]; then
+    test_package_args+=" --test-package-dir=${TEST_PACKAGE_DIR-}"
+  fi
+  if [[ -n ${TEST_PACKAGE_BUCKET-} ]]; then
+    test_package_args+=" --test-package-bucket=${TEST_PACKAGE_BUCKET-}"
+  fi
+else
+  test_package_args+=" --test-package-version=${TEST_PACKAGE_VERSION}"
+fi
+
+# shellcheck disable=SC2086
 ${KUBETEST2} \
-		--cloud-provider="${CLOUD_PROVIDER}" \
-		--kops-binary-path="${KOPS}" \
-		--test=kops \
-		-- \
-		--test-package-version="${K8S_VERSION_B}" \
-		--parallel 25
+    --cloud-provider="${CLOUD_PROVIDER}" \
+    --kops-binary-path="${KOPS}" \
+    --test=kops \
+    -- \
+    $test_package_args \
+    --parallel 25
