@@ -17,6 +17,7 @@ limitations under the License.
 package awstasks
 
 import (
+	"fmt"
 	"sort"
 	"testing"
 
@@ -337,95 +338,83 @@ terraform {
 	doRenderTests(t, "RenderTerraform", cases)
 }
 
-func TestAutoscalingGroupCloudformationRender(t *testing.T) {
-	cases := []*renderTest{
+func TestTGsARNsChunks(t *testing.T) {
+	var tgsARNs []*string
+	for i := 0; i < 30; i++ {
+		tgsARNs = append(tgsARNs, fi.PtrTo(fmt.Sprintf("arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-targets/00000000000000%02d", i)))
+	}
+
+	tests := []struct {
+		tgsARNs   []*string
+		chunkSize int
+		expected  [][]*string
+	}{
 		{
-			Resource: &AutoscalingGroup{
-				Name:                   fi.String("test1"),
-				LaunchTemplate:         &LaunchTemplate{Name: fi.String("test_lt")},
-				MaxSize:                fi.Int64(10),
-				Metrics:                []string{"test"},
-				MinSize:                fi.Int64(5),
-				MixedInstanceOverrides: []string{"t2.medium", "t2.large"},
-				MixedOnDemandBase:      fi.Int64(4),
-				MixedOnDemandAboveBase: fi.Int64(30),
-				Subnets: []*Subnet{
-					{
-						Name: fi.String("test-sg"),
-						ID:   fi.String("sg-1111"),
-					},
-				},
-				Tags: map[string]string{
-					"test":    "tag",
-					"cluster": "test",
-				},
-			},
-			Expected: `{
-  "Resources": {
-    "AWSAutoScalingAutoScalingGrouptest1": {
-      "Type": "AWS::AutoScaling::AutoScalingGroup",
-      "Properties": {
-        "AutoScalingGroupName": "test1",
-        "MaxSize": "10",
-        "MinSize": "5",
-        "VPCZoneIdentifier": [
-          {
-            "Ref": "AWSEC2Subnettestsg"
-          }
-        ],
-        "Tags": [
-          {
-            "Key": "cluster",
-            "Value": "test",
-            "PropagateAtLaunch": true
-          },
-          {
-            "Key": "test",
-            "Value": "tag",
-            "PropagateAtLaunch": true
-          }
-        ],
-        "MetricsCollection": [
-          {
-            "Granularity": null,
-            "Metrics": [
-              "test"
-            ]
-          }
-        ],
-        "MixedInstancesPolicy": {
-          "LaunchTemplate": {
-            "LaunchTemplateSpecification": {
-              "LaunchTemplateId": {
-                "Ref": "AWSEC2LaunchTemplatetest_lt"
-              },
-              "Version": {
-                "Fn::GetAtt": [
-                  "AWSEC2LaunchTemplatetest_lt",
-                  "LatestVersionNumber"
-                ]
-              }
-            },
-            "Overrides": [
-              {
-                "InstanceType": "t2.medium"
-              },
-              {
-                "InstanceType": "t2.large"
-              }
-            ]
-          },
-          "InstancesDistribution": {
-            "OnDemandBaseCapacity": 4,
-            "OnDemandPercentageAboveBaseCapacity": 30
-          }
-        }
-      }
-    }
-  }
-}`,
+			tgsARNs:   tgsARNs[0:1],
+			chunkSize: 10,
+			expected:  [][]*string{tgsARNs[0:1]},
+		},
+		{
+			tgsARNs:   tgsARNs[0:5],
+			chunkSize: 10,
+			expected:  [][]*string{tgsARNs[0:5]},
+		},
+		{
+			tgsARNs:   tgsARNs[0:10],
+			chunkSize: 10,
+			expected:  [][]*string{tgsARNs[0:10]},
+		},
+		{
+			tgsARNs:   tgsARNs[0:11],
+			chunkSize: 10,
+			expected:  [][]*string{tgsARNs[0:10], tgsARNs[10:11]},
+		},
+		{
+			tgsARNs:   tgsARNs[0:15],
+			chunkSize: 10,
+			expected:  [][]*string{tgsARNs[0:10], tgsARNs[10:15]},
+		},
+		{
+			tgsARNs:   tgsARNs[0:20],
+			chunkSize: 10,
+			expected:  [][]*string{tgsARNs[0:10], tgsARNs[10:20]},
+		},
+		{
+			tgsARNs:   tgsARNs[0:21],
+			chunkSize: 10,
+			expected:  [][]*string{tgsARNs[0:10], tgsARNs[10:20], tgsARNs[20:21]},
+		},
+		{
+			tgsARNs:   tgsARNs[0:25],
+			chunkSize: 10,
+			expected:  [][]*string{tgsARNs[0:10], tgsARNs[10:20], tgsARNs[20:25]},
+		},
+		{
+			tgsARNs:   tgsARNs[0:30],
+			chunkSize: 10,
+			expected:  [][]*string{tgsARNs[0:10], tgsARNs[10:20], tgsARNs[20:30]},
 		},
 	}
 
-	doRenderTests(t, "RenderCloudformation", cases)
+	for i, test := range tests {
+		result := sliceChunks(test.tgsARNs, test.chunkSize)
+
+		expected, err := yaml.Marshal(test.expected)
+		if err != nil {
+			t.Errorf("case %d: failed to convert expected to yaml: %v", i, err)
+			continue
+		}
+
+		actual, err := yaml.Marshal(result)
+		if err != nil {
+			t.Errorf("case %d: failed to convert actual to yaml: %v", i, err)
+			continue
+		}
+
+		if string(expected) != string(actual) {
+			diffString := diff.FormatDiff(string(expected), string(actual))
+			t.Errorf("case %d: actual output differed from expected", i)
+			t.Logf("diff:\n%s\n", diffString)
+		}
+	}
 }
