@@ -31,8 +31,13 @@ import (
 	"strings"
 	"time"
 
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/aws/ec2metadata"
+	"github.com/aws/aws-sdk-go/aws/session"
+	"github.com/aws/aws-sdk-go/service/autoscaling"
+	"github.com/aws/aws-sdk-go/service/ec2"
 	"github.com/aws/aws-sdk-go/service/kms"
-
+	"k8s.io/klog/v2"
 	"k8s.io/kops/nodeup/pkg/model"
 	"k8s.io/kops/nodeup/pkg/model/dns"
 	"k8s.io/kops/nodeup/pkg/model/networking"
@@ -56,12 +61,6 @@ import (
 	"k8s.io/kops/util/pkg/architectures"
 	"k8s.io/kops/util/pkg/distributions"
 	"k8s.io/kops/util/pkg/vfs"
-
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/ec2metadata"
-	"github.com/aws/aws-sdk-go/aws/session"
-	"github.com/aws/aws-sdk-go/service/autoscaling"
-	"k8s.io/klog/v2"
 )
 
 // MaxTaskDuration is the amount of time to keep trying for; we retry for a long time - there is not really any great fallback
@@ -178,11 +177,16 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 		return fmt.Errorf("no instance group defined in nodeup config")
 	}
 
-	if bootConfig.NodeupConfigHash != base64.StdEncoding.EncodeToString(nodeupConfigHash[:]) {
-		return fmt.Errorf("nodeup config hash mismatch")
+	if want, got := bootConfig.NodeupConfigHash, base64.StdEncoding.EncodeToString(nodeupConfigHash[:]); got != want {
+		return fmt.Errorf("nodeup config hash mismatch (was %q, expected %q)", got, want)
 	}
 
-	err = evaluateSpec(c, &nodeupConfig)
+	cloudProvider := api.CloudProviderID(bootConfig.CloudProvider)
+	if cloudProvider == "" {
+		cloudProvider = c.cluster.Spec.GetCloudProvider()
+	}
+
+	err = evaluateSpec(c, &nodeupConfig, cloudProvider)
 	if err != nil {
 		return err
 	}
@@ -208,7 +212,7 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 
 	var cloud fi.Cloud
 
-	if api.CloudProviderID(c.cluster.Spec.CloudProvider) == api.CloudProviderAWS {
+	if cloudProvider == api.CloudProviderAWS {
 		awsCloud, err := awsup.NewAWSCloud(region, nil)
 		if err != nil {
 			return err
@@ -217,14 +221,15 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 	}
 
 	modelContext := &model.NodeupModelContext{
-		Cloud:        cloud,
-		Architecture: architecture,
-		Assets:       assetStore,
-		Cluster:      c.cluster,
-		ConfigBase:   configBase,
-		Distribution: distribution,
-		BootConfig:   &bootConfig,
-		NodeupConfig: &nodeupConfig,
+		Cloud:         cloud,
+		CloudProvider: cloudProvider,
+		Architecture:  architecture,
+		Assets:        assetStore,
+		Cluster:       c.cluster,
+		ConfigBase:    configBase,
+		Distribution:  distribution,
+		BootConfig:    &bootConfig,
+		NodeupConfig:  &nodeupConfig,
 	}
 
 	var secretStore fi.SecretStore
@@ -263,7 +268,7 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 		return err
 	}
 
-	if api.CloudProviderID(c.cluster.Spec.CloudProvider) == api.CloudProviderAWS {
+	if cloudProvider == api.CloudProviderAWS {
 		instanceIDBytes, err := vfs.Context.ReadFile("metadata://aws/meta-data/instance-id")
 		if err != nil {
 			return fmt.Errorf("error reading instance-id from AWS metadata: %v", err)
@@ -295,7 +300,12 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 				modelContext.GPUVendor = architectures.GPUVendorNvidia
 			}
 		}
-
+	} else if cloudProvider == api.CloudProviderOpenstack {
+		// NvidiaGPU possible to enable only in instance group level in OpenStack. When we assume that GPU is supported
+		if nodeupConfig.NvidiaGPU != nil && fi.BoolValue(nodeupConfig.NvidiaGPU.Enabled) {
+			klog.Info("instance supports GPU acceleration")
+			modelContext.GPUVendor = architectures.GPUVendorNvidia
+		}
 	}
 
 	if err := loadKernelModules(modelContext); err != nil {
@@ -394,7 +404,7 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 	}
 
 	if nodeupConfig.EnableLifecycleHook {
-		if api.CloudProviderID(c.cluster.Spec.CloudProvider) == api.CloudProviderAWS {
+		if cloudProvider == api.CloudProviderAWS {
 			err := completeWarmingLifecycleAction(cloud.(awsup.AWSCloud), modelContext)
 			if err != nil {
 				return fmt.Errorf("failed to complete lifecylce action: %w", err)
@@ -449,8 +459,8 @@ func completeWarmingLifecycleAction(cloud awsup.AWSCloud, modelContext *model.No
 	return nil
 }
 
-func evaluateSpec(c *NodeUpCommand, nodeupConfig *nodeup.Config) error {
-	hostnameOverride, err := evaluateHostnameOverride(api.CloudProviderID(c.cluster.Spec.CloudProvider), nodeupConfig.UseInstanceIDForNodeName)
+func evaluateSpec(c *NodeUpCommand, nodeupConfig *nodeup.Config, cloudProvider api.CloudProviderID) error {
+	hostnameOverride, err := evaluateHostnameOverride(cloudProvider, nodeupConfig.UseInstanceIDForNodeName)
 	if err != nil {
 		return err
 	}
@@ -483,15 +493,46 @@ func evaluateSpec(c *NodeUpCommand, nodeupConfig *nodeup.Config) error {
 func evaluateHostnameOverride(cloudProvider api.CloudProviderID, useInstanceIDForNodeName bool) (string, error) {
 	switch cloudProvider {
 	case api.CloudProviderAWS:
-		source := "local-hostname"
-		if useInstanceIDForNodeName {
-			source = "instance-id"
-		}
-		nodeNameBytes, err := vfs.Context.ReadFile("metadata://aws/meta-data/" + source)
+		instanceIDBytes, err := vfs.Context.ReadFile("metadata://aws/meta-data/instance-id")
 		if err != nil {
-			return "", fmt.Errorf("error reading %s from AWS metadata: %v", source, err)
+			return "", fmt.Errorf("error reading instance-id from AWS metadata: %v", err)
 		}
-		return string(nodeNameBytes), nil
+		instanceID := string(instanceIDBytes)
+
+		if useInstanceIDForNodeName {
+			return instanceID, nil
+		}
+
+		azBytes, err := vfs.Context.ReadFile("metadata://aws/meta-data/placement/availability-zone")
+		if err != nil {
+			return "", fmt.Errorf("error reading availability zone from AWS metadata: %v", err)
+		}
+
+		config := aws.NewConfig()
+		config = config.WithCredentialsChainVerboseErrors(true)
+
+		s, err := session.NewSession(config)
+		if err != nil {
+			return "", fmt.Errorf("error starting new AWS session: %v", err)
+		}
+
+		svc := ec2.New(s, config.WithRegion(string(azBytes[:len(azBytes)-1])))
+
+		result, err := svc.DescribeInstances(&ec2.DescribeInstancesInput{
+			InstanceIds: []*string{&instanceID},
+		})
+		if err != nil {
+			return "", fmt.Errorf("error describing instances: %v", err)
+		}
+
+		if len(result.Reservations) > 1 {
+			return "", fmt.Errorf("too many reservations returned for the single instance-id")
+		}
+		if len(result.Reservations[0].Instances) > 1 {
+			return "", fmt.Errorf("too many instances returned for the single instance-id")
+		}
+
+		return *(result.Reservations[0].Instances[0].PrivateDnsName), nil
 
 	case api.CloudProviderGCE:
 		// This lets us tolerate broken hostnames (i.e. systemd)
@@ -517,20 +558,6 @@ func evaluateHostnameOverride(cloudProvider api.CloudProviderID, useInstanceIDFo
 		}
 
 		return hostname, nil
-	case api.CloudProviderALI:
-		azBytes, err := vfs.Context.ReadFile("metadata://alicloud/zone-id")
-		if err != nil {
-			return "", fmt.Errorf("error reading zone-id from Alicloud metadata: %v", err)
-		}
-		az := string(azBytes)
-
-		instanceIDBytes, err := vfs.Context.ReadFile("metadata://alicloud/instance-id")
-		if err != nil {
-			return "", fmt.Errorf("error reading instance-id from Alicloud metadata: %v", err)
-		}
-		instanceID := string(instanceIDBytes)
-
-		return fmt.Sprintf("%s.%s", az, instanceID), nil
 	}
 
 	return "", nil
