@@ -89,6 +89,11 @@ func TestFindDistribution(t *testing.T) {
 			err:      nil,
 			expected: DistributionRhel8,
 		},
+		{
+			rootfs:   "rocky8",
+			err:      nil,
+			expected: DistributionRocky8,
+		},
 		{
 			rootfs:   "ubuntu1604",
 			err:      fmt.Errorf("unsupported distro: ubuntu-16.04"),
@@ -96,8 +101,8 @@ func TestFindDistribution(t *testing.T) {
 		},
 		{
 			rootfs:   "ubuntu1804",
-			err:      fmt.Errorf("unsupported distro: ubuntu-18.04"),
-			expected: Distribution{},
+			err:      nil,
+			expected: DistributionUbuntu1804,
 		},
 		{
 			rootfs:   "ubuntu2004",
